HeapPtr

Struct HeapPtr 

pub struct HeapPtr<T> { /* private fields */ }
light weight smart pointer that owns memory using HeapAlloc and HeapFree as it’s allocation and deallocation mechanisms.

Implementations

Source

impl<T> HeapPtr<T>

pub fn new(size: usize) -> Self

pub const fn from_raw(ptr: *mut T) -> Self

pub fn from_slice(slice: &[T]) -> Result<Self, AbiError>

pub const fn as_ptr(&self) -> *const T

pub const fn as_mut_ptr(&self) -> *mut T

pub fn into_raw(self) -> *mut T

Consumes the wrapper and returns the raw pointer, skipping deallocation.

pub const fn is_null(&self) -> bool

Returns true if the internal pointer is null.